@@ -15,6 +15,8 @@ pub struct Framework {
 	pub beacon_map_json: Json,
 	pub entry_types_json: Json,
 	pub result_sets_json: Json,
+	pub boolean_json: Json,
+	pub count_json: Json,
 	files: BTreeMap<PathBuf, Json>,
 }
 
@@ -27,7 +29,7 @@ impl Framework {
 			utils::copy_dir_recursively(location.path(), &dir).expect("Copy dir recursively failed");
 		}
 		else {
-			// Parse spec repo URL
+			// Parse model repo URL
 			assert_eq!(
 				location.domain().unwrap_or(""),
 				"github.com",
@@ -55,6 +57,8 @@ impl Framework {
 			beacon_map_json: Json::Null,
 			entry_types_json: Json::Null,
 			result_sets_json: Json::Null,
+			boolean_json: Json::Null,
+			count_json: Json::Null,
 			files: BTreeMap::new(),
 		};
 
@@ -95,6 +99,16 @@ impl Framework {
 			.get(&base_path.join("responses").join("beaconEntryTypesResponse.json"))
 			.expect("beaconEntryTypesResponse.json not found")
 			.clone();
+		self.boolean_json = self
+			.files
+			.get(&base_path.join("responses").join("beaconBooleanResponse.json"))
+			.expect("beaconBooleanResponse.json not found")
+			.clone();
+		self.count_json = self
+			.files
+			.get(&base_path.join("responses").join("beaconCountResponse.json"))
+			.expect("beaconCountResponse.json not found")
+			.clone();
 		self.result_sets_json = self
 			.files
 			.get(&base_path.join("responses").join("beaconResultsetsResponse.json"))
